![alt text](x_start.png)

#*Welcome to Loge*

*Easy and fast dynamic report generation with Python*

---

If you are a new Loge user go to Info to get information and try to use it with prepared tutorial.


Please not that this is beta version - for testing.


